# xremap-python

Generate an xremap config with a Python DSL.

## Installation

```bash
$ pip install xremap
```

This will install `xremap-python` command.

## Usage

```bash
$ xremap-python example/config.py > config.yml
$ sudo xremap config.yml
```

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
